@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -169,7 +169,6 @@ BEGIN {
 							value => $options 
 						};
 					}
-
 					$PRO{set_prop}(
 						$caller,
 						$prop,
@@ -449,9 +448,57 @@ sub new {
 
 	$pkg->set_meta($meta, $name);
 
+	if (grep { $_ eq 'Rope::Monkey' } @{$meta->{use}}) {
+		$meta->{name}->monkey();
+	}
+
 	return $PRO{new}($name)($name, %params);
 }
 
+sub from_data {
+	my ($pkg, $data, $meta) = @_;
+
+	$meta ||= {};
+	$meta->{name} ||= 'Rope::Anonymous' . $META{ANONYMOUS}++;
+
+	for (keys %{$data}) {
+		$meta->{properties}->{$_} = {
+			value => $data->{$_},
+			writeable => 1,
+			enumerable => 1
+		};
+	}
+
+	return $pkg->new($meta)->new();
+}
+
+sub from_nested_data {
+	my ($pkg, $data, $meta) = @_;
+
+	$data = $PRO{clone}($data);
+
+	for my $d (keys %{$data}) {
+		my $ref = ref $data->{$d};
+		if ($ref eq 'HASH') {
+			$data->{$d} = $pkg->from_nested_data($data->{$d}, $meta);
+		} elsif ($ref eq 'ARRAY') {
+			for (my $i = 0; $i < scalar @{$data->{$d}}; $i++) {
+				my $val = $data->{$d}->[$i];
+				my $rref = ref $val || "";
+				if ($rref eq 'HASH') {
+					$val = $pkg->from_nested_data(
+						$val,
+						$meta
+					);
+					$data->{$d}->[$i] = $val;
+				}
+			}
+		}
+	}
+
+	return $pkg->from_data($data, $meta);
+}
+
 sub get_initialised {
 	my ($self, $caller, $init) = @_;
 	return $META{initialised}{$caller}{$init};
@@ -498,7 +545,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.24
+Version 0.25
 
 =cut
 
@@ -889,6 +936,57 @@ Extend or redefine an object meta definition.
 
 	Hitch->new->one;
 
+=head2 from_data
+
+Initialise a Rope object from a perl hash struct.
+
+	my $obj = Rope::Object->from_data({
+		one => 1,
+		two => {
+			a => 1,
+			b => 2
+		},
+		three => [
+			{
+				a => 1,
+				b => 2	
+			}
+		]
+	}, { use => 'Rope::Monkey' });
+
+	...
+
+	$obj->one;
+	$obj->two->{a};
+	$obj->three->[0]->{a};
+
+
+=head2 from_nested_data
+
+Initialise a Rope object from a nested perl hash struct.
+
+	my $obj = Rope::Object->from_nested_data({
+		one => 1,
+		two => {
+			a => 1,
+			b => 2
+		},
+		three => [
+			{
+				a => 1,
+				b => 2	
+			}
+		]
+	}, { use => 'Rope::Autoload' });
+
+	...
+
+	$obj->one;
+	$obj->two->a;
+	$obj->three->[0]->a;
+
+NOTE: this generates an object definition per array item so in many cases it is better you define your object definitions yourself and then write the relevant logic to initialise them. I will eventually look into perhaps itterating all items finding all unique keys and then initialiasing, that will just take a bit more time though.
+
 =head1 OBJECT CLASS DEFINITION
 
 	package Builder;
@@ -919,7 +1017,6 @@ Extend or redefine an object meta definition.
 
 	1;
 
-
 =head1 OBJECT ROLE DEFINITION
 
 	package Builder::Role;
