@@ -48,7 +48,7 @@ sub import {
 	my $caller = scalar(caller);
 	$PRO{keyword}($caller, 'monkey', sub {
 		my $self = shift;
-		if ($self) {
+		if (ref $self) {
 			while (@_) {
 				my ($prop, $options) = (shift @_, shift @_);
 				$self->{$prop} = $options;
@@ -69,7 +69,7 @@ Rope::Monkey - Rope Monkey Patching
 
 =head1 VERSION
 
-Version 0.24
+Version 0.25
 
 =cut
 
